;; Generated package description from beframe.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "beframe" "1.5.0.0.20260827.16" "Isolate buffers per frame" '((emacs "28.1")) :commit "3ee3f53ada6b4dc1d8a490b68daab367248a98d7" :authors '(("Protesilaos" . "info@protesilaos.com")) :maintainer '("Protesilaos" . "info@protesilaos.com") :url "https://github.com/protesilaos/beframe")
